@@ -9,6 +9,8 @@
 BEGIN { $| = 1; print "1..1\n"; }
 END {print "not ok 1\n" unless $loaded;}
 $loaded = 1;
+use SAP::BC;
+use SAP::BC::XMLRFC;
 print "ok 1\n";
 
 ######################### End of black magic.
